import {useEffect, useRef, useState} from "react";
import * as events from "events";


export default function Modal({isOpen, onClose, children}){

    const [isModalOpen, setModalOpen] = useState(false);
    const modalRef = useRef();

    useEffect(() => {
        setModalOpen(isOpen);
    }, [isOpen]);

    useEffect(() => {
        const modalElement = modalRef.current;
        if (modalElement) {
            if (isModalOpen) {
                modalElement.showModal();
            } else {
                modalElement.close();
            }
        }
    }, [isModalOpen]);

    const handleKeyDown = (event) => {
        if(event.key === "Escape"){
            onClose()
            setModalOpen(false)
        }
    }

    return (
        <dialog onKeyDown={handleKeyDown} ref={modalRef}
                className={'h-screen max-h-screen ml-0 bg-gray-300 shadow shadow-gray-500 rounded-[4px] p-3 backdrop:backdrop-blur-sm backdrop:bg-white/30 backdrop:duration-700'}>
            {children}
        </dialog>
    )
}