import React, {useState} from "react";
import people from "../../../assets/svg/people.svg"
import stars from "../../../assets/svg/stars.svg"
import tournament from "../../../assets/svg/tournament.svg"
import peopleCard from "../../../assets/images/alex-shuper-aXgYJtVA3A8-unsplash.jpg"
import tournamentCard from "../../../assets/images/igor-omilaev-ToxUgLe7tpE-unsplash.jpg"
import starsCard from "../../../assets/images/jigar-panchal-4slT2XvKnio-unsplash.jpg"

const Highlights = ({imgSrc, imgAlt, desc, handleFlipState}) => (
    <div onClick={handleFlipState}
         className='flex flex-col items-center max-w-[345px] min-h-[250px] bg-lightGray rounded-2xl'>
        <img src={imgSrc} alt={imgAlt} className='w-[70px] h-[70px]'/>
        <div className='text-darkGray text-center font-outfit font-medium text-2xl'>
            {desc}
        </div>
    </div>
)

const CardFlip = ({imgSrc, imgSrc2, imgAlt, desc, desc2}) => {

    const [flipState, setFlipState] = useState(false);

    const handleFlipState = () => {
        setFlipState(!flipState)
    }

    return (
        <div className='flex flex-col max-w-[345px] min-h-[250px]'>
            {flipState ? (
                <Highlights imgSrc={imgSrc} imgAlt={imgAlt} desc={desc} handleFlipState={handleFlipState}/>
            ) : (
                <button onClick={handleFlipState}
                        className='border-2 border-lightGray rounded-2xl w-[345px] h-full bg-cover relative max-lg:h-[250px]'
                        style={{backgroundImage: `url(${imgSrc2})`}}>
                    <div
                        className='absolute bottom-0 left-0 right-0 p-4 text-4xl text-lightGray border-t-2 border-lightGray rounded-2xl'>{desc2}</div>
                </button>
            )}
        </div>
    )
};

const Features = () => {
    return (
        <div className='flex flex-col items-center gap-10 max-w-[1065px] min-h-[450px] ms-auto me-auto bg-deepPurple'>
            <div
                className='flex justify-center items-center text-darkGray font-Outfit-ExtraBold font-bold text-7xl uppercasen m-auto'>
                How it works
            </div>
            <div className='flex gap-2 max-lg:flex max-lg:flex-col m-auto'>
                <CardFlip imgSrc={people} imgAlt='People' imgSrc2={peopleCard} desc2='People'
                          desc='Bring People together and Game'/>
                <CardFlip imgSrc={tournament} imgAlt='Tournament' imgSrc2={tournamentCard}
                          desc='Create your type of Tournament and let our Engine handle your Experience. Anything is possible'
                          desc2='Tournament'/>
                <CardFlip imgSrc={stars} imgAlt='Stars' imgSrc2={starsCard}
                          desc='Bring on your Winner of the Tournament and give out MVP Medals for the best Players'
                          desc2='Stars'/>
            </div>
        </div>
    )
}

export default Features