import React, {useEffect, useState} from "react";
import Pic1 from '../../../assets/images/siviwe-kapteyn-tCvDVszXdHE-unsplash.jpg'
import Pic2 from '../../../assets/images/devin-avery-lhAy4wmkjSk-unsplash.jpg'
import Pic3 from '../../../assets/images/jed-villejo-pumko2FFxY0-unsplash.jpg'

const arrSlides = [{url: Pic1, text:'Handles well'}, {url: Pic2, text: 'Sun is shining'}, {url: Pic3}]

const Card = () => {
    const [currentSlide, setCurrentSlide] = useState(0)
    const [progress, setProgress] = useState(0)

    const handleNext = () => {
        setCurrentSlide((prevSlide) => (prevSlide + 1) % arrSlides.length)
        setProgress(0)
    }

    const handlePrevious = () => {
        setCurrentSlide((prevSlide) => (prevSlide - 1 + arrSlides.length) % arrSlides.length)
        setProgress(0)
    }

    const switchToNextCard = () => {
        setCurrentSlide((prevSlide) => (prevSlide + 1) % arrSlides.length)
        setProgress(0)
    };

    useEffect(() => {
        const intervalId = setInterval(switchToNextCard, 5000)
        return () => clearInterval(intervalId)
    }, []);

    useEffect(() => {
        const intervalId = setInterval(() => {
            setProgress((prevProgress) => {
                const newProgress = prevProgress + (100/5000) * 100
                return newProgress >= 100 ? 0 : newProgress
            })
        }, 100)

        return() => clearInterval(intervalId)
    }, []);

    return (
        <div className='flex flex-col items-center'>
            <div className='flex items-center'>
                <button
                    className='bg-lightGray text-darkGray px-2 py-1 mx-2 rounded-full z-10 max-lg:hidden'
                    onClick={handlePrevious}>
                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5}
                         stroke="currentColor" className="w-6 h-6">
                        <path strokeLinecap="round" strokeLinejoin="round" d="M15.75 19.5L8.25 12l7.5-7.5"/>
                    </svg>
                </button>
                <div className='flex gap-5 relative z-10'>
                    {arrSlides.map((slide, index) => (
                        <div
                            key={index}
                            className={`bg-lightGray h-[370px] w-[75px] bg-cover rounded-2xl cursor-pointer text-deepPurple text-2xl text-center ${
                                index === currentSlide ? 'scale-110 w-[320px]' : ''
                            } transition-transform duration-300`}
                            style={{backgroundImage: `url(${slide.url})`}}
                        >{slide.text}
                        </div>
                    ))}
                </div>
                <button
                    className='bg-lightGray text-darkGray px-2 py-1 rounded-full cursor-pointer z-10 mx-2 max-lg:hidden'
                    onClick={handleNext}>
                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5}
                         stroke="currentColor" className="w-6 h-6">
                        <path strokeLinecap="round" strokeLinejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5"/>
                    </svg>
                </button>
            </div>
            <div className='mt-10 mb-2 w-80'>
                <div
                    className='h-2 bg-deepPurple rounded-2xl'
                    style={{width: `${progress}%`}}
                ></div>
            </div>
        </div>
    )
}


const Modes = () => {
    return (
        <div className='max-w-[1065x] max-h-[540px] max-[1024px]:max-h-[540px] max-[1024px]:mb-40'>
            <div
                className='flex gap-10 justify-around items-center bg-darkGray max-w-[1065px] min-h-[540px] ms-auto me-auto max-lg:flex-col max-lg:max-h-[540px] max-lg:items-center max-lg:justify-center'>
                <Card/>
                <div className='flex flex-col w-[525px] h-[370px] gap-10'>
                    <h2 className='text-lightGray font-Outfit-ExtraBold font-bold text-7xl uppercase m-auto'>
                        Everything <br/> is possible
                    </h2>
                    <p className='text-lightGray font-Outfit-Regular font-medium text-xl max-w-md m-auto'>
                        Create any Type of Tournament possible. With our new Tournament Engine
                        everything is in the Hand of you. Grab your Friends and lets GAME
                    </p>
                </div>
            </div>
            <div className='flex justify-end mr-[5%] transform: -translate-y-96'>
                <div
                    className='bg-deepPurple rounded-[50%] w-[496px] h-[485px] filter blur-[250px] opacity-40 animate-spin-slow'></div>
            </div>
        </div>
    )
}

export default Modes