import React, {useState} from "react";
import {Link} from "react-router-dom";
import menu from '../../../assets/svg/menu.svg'

const Navbar = () => {
    const [darkMode, setDarkMode] = useState(true)
    const [showMenu, setShowMenu] =useState(false)

    const toggleDarkMode = () => {
        setDarkMode(!darkMode)
    };
    
    const toggleMenu = () => {
      setShowMenu(!showMenu)
    }

    const backgroundColorClasses = darkMode ? 'bg-darkGray': 'bg-lightGray';
    const textClass = darkMode ? 'text-lightGray': 'text-darkGray';
    const moonOrSunIcon = darkMode ? '☾': '☼' ;


    return (
        <div className={`${backgroundColorClasses} fixed top-0 z-50`}>
            <nav className={`flex ${textClass} gap-3 items-center justify-center`}>
                <div className='flex flex-row gap-5 items-center justify-center flex-shrink-0 w-screen relative'>
                    <button onClick={toggleMenu} className='hidden max-[1024px]:flex'>
                        <img src={menu} alt='Menu' className='w-6 h-6'/>
                    </button>
                    {showMenu && (
                        <div className="lg:hidden absolute top-16 left-0 right-0 bg-lightGray text-darkGray">
                            <ul className="flex flex-col items-start justify-start w-full px-4 py-2">
                                <li className="hover:underline hover:underline-offset-4 hover:decoration-2">
                                    <Link to="/landingpage">
                                        Home
                                    </Link>
                                </li>
                                <li className="hover:underline hover:underline-offset-4 hover:decoration-2">
                                    <Link to="/landingpage">
                                        Tournaments
                                    </Link>
                                </li>
                                <li className="hover:underline hover:underline-offset-4 hover:decoration-2">
                                    <Link to="/landingpage">
                                        Support
                                    </Link>
                                </li>
                                <li className="hover:underline hover:underline-offset-4 hover:decoration-2">
                                    <Link to="/landingpage">
                                        Options
                                    </Link>
                                </li>
                            </ul>
                        </div>
                    )}
                    <div
                        className='flex flex-row flex-shrink-0 gap-0 items-center justify-start relative p-2.5 text-5xl'>TJ1
                    </div>
                    <div className='flex flex-col items-start justify-start flex-shrink-0 relative gap-2.5 p-2.5 max-[1024px]:hidden'>
                        <ul className='flex flex-row items-start justify-start flex-shrink-0 w-1/3 relative px-4 gap-8 text-xl'>
                            <li className='hover:underline hover:underline-offset-4 hover:decoration-2'>
                                <Link to="/landingpage">Home</Link>
                            </li>
                            <li className='hover:underline hover:underline-offset-4 hover:decoration-2'>
                                <Link to="/landingpage">Tournaments</Link>
                            </li>
                            <li className='hover:underline hover:underline-offset-4 hover:decoration-2'>
                                <Link to="/landingpage">Support</Link>
                            </li>
                            <li className='hover:underline hover:underline-offset-4 hover:decoration-2'>
                                <Link to="/landingpage">Options</Link>
                            </li>
                        </ul>
                    </div>
                    <div onClick={toggleDarkMode} className='cursor-pointer text-3xl'>
                        {moonOrSunIcon}
                    </div>
                    <div className='flex flex-row items-center justify-start flex-shrink-0 relative gap-5'>
                        <button
                            className='w-40 rounded-3xl border-2 border-lightGray px-12 py-2 bg-lightGray text-darkGray hover:bg-darkGray hover:text-lightGray bg-[#C2C2C2] hover: border-[#C2C2C2]'>
                            Register
                        </button>
                        <button className='w-40 rounded-3xl border-2 px-12 py-2 hover:bg-deepPurple'>
                            Login
                        </button>
                    </div>
                </div>
            </nav>
        </div>
    )
}

export default Navbar